svn: pear/peardoc/trunk/scripts/

[email protected] ("Brett Bieber")
Newsgroups php.pear.doc
Message-ID <[email protected]>
saltybeagle		Sat, 11 Jul 2009 13:28:36 +0000

ViewVC URL: http://svn.php.net/viewvc?view=revision&revision=283869

Changed paths:
	U   pear/peardoc/trunk/scripts/pearwebbuild.php

Log:
CVS->SVN conversion for pear manual build script.

Modified: pear/peardoc/trunk/scripts/pearwebbuild.php
===================================================================
--- pear/peardoc/trunk/scripts/pearwebbuild.php	2009-07-11 11:55:27 UTC (rev 283868)
+++ pear/peardoc/trunk/scripts/pearwebbuild.php	2009-07-11 13:28:36 UTC (rev 283869)
@@ -7,7 +7,7 @@
  * Used at http://pear.php.net/ and
  * http://ucommbieber.unl.edu/peardoc/build/, rsync://ucommbieber.unl.edu/peardoc
  *
  * Usage: php pearwebuild.php [--updatecvs] [--updatephd]
  */
 $php_executable  = 'php';
 $phd_executable  = 'phd';
@@ -23,14 +23,14 @@
 $parser = new Console_CommandLine();
 $parser->description = 'Builds the full manual';
 $parser->version = '$Id$';
-$parser->addOption('updatecvs', array(
-    'long_name'   => '--updatecvs',
-    'description' => 'Update peardoc from CVS',
+$parser->addOption('updatesvn', array(
+    'long_name'   => '--updatesvn',
+    'description' => 'Update peardoc from SVN',
     'action'      => 'StoreTrue'
 ));
 $parser->addOption('updatephd', array(
     'long_name'   => '--updatephd',
-    'description' => 'Update phd from CVS',
+    'description' => 'Update phd from SVN',
     'action'      => 'StoreTrue'
 ));
 $parser->addOption('phpdir', array(
@@ -56,17 +56,17 @@
 }


-if ($cmdline->options['updatecvs']) {
+if ($cmdline->options['updatesvn']) {
     chdir(dirname(dirname(dirname(__FILE__))));
-    // Update cvs
-    shell_exec('cvs -q -d :pserver:[email protected]:/repository checkout peardoc');
+    // Update svn
+    shell_exec('svn checkout http://svn.php.net/repository/pear/peardoc/trunk peardoc');
 }


 if ($cmdline->options['updatephd']) {
     chdir(dirname(dirname(dirname(__FILE__))));
-    // Update cvs
-    shell_exec('cvs -q -d :pserver:[email protected]:/repository checkout phd');
+    // Update svn
+    shell_exec('svn checkout http://svn.php.net/repository/phd/trunk phd');
     // Update phd
     shell_exec($pear_executable.' upgrade -f '.dirname(dirname(dirname(__FILE__))).'/phd/package.xml');
 }
@@ -7,7 +7,7 @@
  * http://ucommbieber.unl.edu/peardoc/build/, rsync://ucommbieber.unl.edu/peardoc
  *
- * Usage: php pearwebuild.php [--updatecvs] [--updatephd]
+ * Usage: php pearwebuild.php [--updatesvn] [--updatephd]
  */
 $php_executable  = 'php';
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.